# ISAAC_SET_PREFIX(PREFIX)
#---------------------------
AC_DEFUN([ISAAC_SET_PREFIX],
[
    unset CDPATH
    # make $PIPE_HOME the default for the installation
    AC_PREFIX_DEFAULT($1)

    if test "x$prefix" = "xNONE"; then
        prefix=$ac_default_prefix
        ac_configure_args="$ac_configure_args --prefix $prefix"
    fi

    if test "x$exec_prefix" = "xNONE"; then
        exec_prefix=$prefix
    fi

])


# ISAAC_SET_VERSION_INFO(VERSION, [CURRENT], [REVISION], [AGE])
#----------------------------------------------------------------
# Setup various version information, especially the libtool versioning
AC_DEFUN([ISAAC_SET_VERSION_INFO],
[
    isaac_version=`echo "$1" | sed -e 's/[[a-z,A-Z]].*$//'`

    isaac_major_version=`echo "$isaac_version" | \
        sed 's/\([[0-9]]*\).\(.*\)/\1/'`
    isaac_minor_version=`echo "$isaac_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\)\(.*\)/\2/'`
    isaac_micro_version=`echo "$isaac_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test -z "$isaac_major_version"; then isaac_major_version=0
    fi

    if test -z "$isaac_minor_version"; then isaac_minor_version=0
    fi

    if test -z "$isaac_micro_version"; then isaac_micro_version=0
    fi

    ISAAC_VERSION="$isaac_version"
    ISAAC_MAJOR_VERSION=$isaac_major_version
    ISAAC_MINOR_VERSION=$isaac_minor_version
    ISAAC_MICRO_VERSION=$isaac_micro_version

    if test -z "$4"; then ISAAC_INTERFACE_AGE=0
    else ISAAC_INTERFACE_AGE="$4"
    fi

    ISAAC_BINARY_AGE=`expr 100 '*' $ISAAC_MINOR_VERSION + $ISAAC_MICRO_VERSION`
    ISAAC_BINARY_VERSION=`expr 10000 '*' $ISAAC_MAJOR_VERSION + \
                          $ISAAC_BINARY_AGE`

    AC_SUBST(ISAAC_VERSION)
    AC_SUBST(ISAAC_MAJOR_VERSION)
    AC_SUBST(ISAAC_MINOR_VERSION)
    AC_SUBST(ISAAC_MICRO_VERSION)
    AC_SUBST(ISAAC_INTERFACE_AGE)
    AC_SUBST(ISAAC_BINARY_VERSION)
    AC_SUBST(ISAAC_BINARY_AGE)

    AC_DEFINE_UNQUOTED(ISAAC_MAJOR_VERSION, $ISAAC_MAJOR_VERSION,
                       [ISAAC major version number])
    AC_DEFINE_UNQUOTED(ISAAC_MINOR_VERSION, $ISAAC_MINOR_VERSION,
                       [ISAAC minor version number])
    AC_DEFINE_UNQUOTED(ISAAC_MICRO_VERSION, $ISAAC_MICRO_VERSION,
                       [ISAAC micro version number])
    AC_DEFINE_UNQUOTED(ISAAC_INTERFACE_AGE, $ISAAC_INTERFACE_AGE,
                       [ISAAC interface age])
    AC_DEFINE_UNQUOTED(ISAAC_BINARY_VERSION, $ISAAC_BINARY_VERSION,
                       [ISAAC binary version number])
    AC_DEFINE_UNQUOTED(ISAAC_BINARY_AGE, $ISAAC_BINARY_AGE,
                       [ISAAC binary age])

    ESO_SET_LIBRARY_VERSION([$2], [$3], [$4])
])


# ISAAC_SET_PATHS
#------------------
# Define auxiliary directories of the installed directory tree.
AC_DEFUN([ISAAC_SET_PATHS],
[

    if test -z "$plugindir"; then
        plugindir='${libdir}/esopipes-plugins/${PACKAGE}-${VERSION}'
    fi

    if test -z "$pipedocsdir"; then
        pipedocsdir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}'
    fi
    htmldir='${pipedocsdir}/html'

    if test -z "$configdir"; then
       configdir='${datadir}/${PACKAGE}/config'
    fi

    if test -z "$privatelibdir"; then
       privatelibdir='${libdir}/${PACKAGE}-${VERSION}'
    fi

    AC_SUBST(plugindir)
    AC_SUBST(htmldir)
    AC_SUBST(configdir)
    AC_SUBST(privatelibdir)
    AC_SUBST(pipedocsdir)


    # Define a preprocesor symbol for the plugin search paths

    AC_DEFINE_UNQUOTED(ISAAC_PLUGIN_DIR, "esopipes-plugins",
                       [Plugin directory tree prefix])

    eval plugin_dir="$plugindir"
    plugin_path=`eval echo $plugin_dir | \
                sed -e "s/\/${PACKAGE}-${VERSION}.*$//"`

    AC_DEFINE_UNQUOTED(ISAAC_PLUGIN_PATH, "$plugin_path",
                       [Absolute path to the plugin directory tree])

])


# ISAAC_CREATE_SYMBOLS
#-----------------------
# Define include and library related makefile symbols
AC_DEFUN([ISAAC_CREATE_SYMBOLS],
[

    # Symbols for package include file and library search paths

    ISAAC_INCLUDES='-I$(top_srcdir)/isaac -I$(top_srcdir)/irplib'
    ISAAC_LDFLAGS='-L$(top_builddir)/isaac'

    all_includes='$(ISAAC_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(ISAAC_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    # Library aliases

    LIBISAAC='$(top_builddir)/isaac/libisaac.la'
    LIBIRPLIB='$(top_builddir)/irplib/libirplib.la'

    # Substitute the defined symbols

    AC_SUBST(ISAAC_INCLUDES)
    AC_SUBST(ISAAC_LDFLAGS)

    AC_SUBST(LIBISAAC)
    AC_SUBST(LIBIRPLIB)

    # Check for CPL and user defined libraries
    AC_REQUIRE([CPL_CHECK_LIBS])
    AC_REQUIRE([ESO_CHECK_EXTRA_LIBS])

    all_includes='$(ISAAC_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(ISAAC_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    AC_SUBST(all_includes)
    AC_SUBST(all_ldflags)
])
