/* $Id: isaac_wavelength.h,v 1.9 2009/07/10 16:20:13 llundin Exp $
 *
 * This file is part of the ISAAC Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: llundin $
 * $Date: 2009/07/10 16:20:13 $
 * $Revision: 1.9 $
 * $Name: isaac-6_1_3 $
 */

#ifndef ISAAC_WAVELENGTH_H
#define ISAAC_WAVELENGTH_H

/*-----------------------------------------------------------------------------
   								Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

/*-----------------------------------------------------------------------------
                                Defines
 -----------------------------------------------------------------------------*/

#define MIN_WAVELENGTH      0.0
#define MAX_WAVELENGTH      1000000.0 /* 100 microns */

/*-----------------------------------------------------------------------------
   							        New types
 -----------------------------------------------------------------------------*/

typedef struct _computed_disprel_ {
    double * poly;    /* List of solution polynomial coefficients */
    int      degree;  /* The degree of the polynomial (currently 3) */
    double   cc;      /* Cross-correlation number, -1 <= cc <= 1 */
    double   mean;    /* Mean line misaligment [pixel] of detected lines */
    double   rms;     /* RMS Mean line misaligment [pixel] of detected lines */
    double   offset;  /* Change in the constant term of the polynomial */
    double   scal1;   /* Scaling of 1st degree coefficient */
    double   scal2;   /* Scaling of 2nd degree coefficient */
    double   scal3;   /* Scaling of 3rd degree coefficient */
    int      clines;  /* Number of catalog lines used in the fit */
    int      dlines;  /* Number of catalog lines detected in the image */
} computed_disprel;

/*-----------------------------------------------------------------------------
   							        Prototypes
 -----------------------------------------------------------------------------*/

computed_disprel * spectro_compute_disprel(const cpl_image *, int, int, int, 
					   int, int, int, const char *, 
					   const char *, const char *,
					   const char *, 
                                           double, int, int, const double *);
int isaac_find_order(const char *);
int isaac_has_thermal(const char *);
double isaac_get_slitwidth(const char *);

#endif
